@@ -17,16 +17,20 @@ from sciscripts.Analysis.Plot import SoundMeasurements as Plot
 print('[CalibratingAudioSetup] Done.')
 
 Parameters = dict(
-    ## Calibration parameters
+    #--- Calibration parameters
     Freq = 10000,       # Frequency of the wave used to calibrate the sound card
     WaveDur = 10,       # Duration of the test wave
     Repetitions = 4,    # How many repetitions to average the input signal
 
 
-    ## Measurements parameters
-    Setup = 'LTSpeakers',     # Setup name - To be provided on further experiments
+    #--- Measurements parameters
+    Setup = 'LTSpeakers',     # Can be any string - To be provided on further experiments
     SoundPulseDur = 2,        # Duration of each pulse at each freq and intensity
-    NoiseFrequency = [        # Noise frequency bands to be calibrated
+
+    # Noise frequency bands to be calibrated
+    # Should contain lists with 2 values, which are the noise frequency range in Hz.
+    # Add as many as you need, as broad or narrow as you need.
+    NoiseFrequency = [
         [8000, 10000],
         [9000, 11000],
         [10000, 12000],
@@ -41,10 +45,10 @@ Parameters = dict(
     # MicSens_VPa = 0.00423643    # If in V/Pa
 
 
-    ## Audio system
+    #--- Audio system
     Rate = 192000,                       # Audio sampling rate
     BlockSize = 384,                     # Audio block size
-    System = 'Jack-IntelOut-IntelIn',    # System name - To be provided on further experiments
+    System = 'Jack-IntelOut-IntelIn',    # Can be any string - To be provided on further experiments
 )
 
 
