@@ -5,6 +5,8 @@
 @year: 20210409
 @license: GNU GPLv3 <https://gitlab.com/malfatti/SciScripts/raw/master/LICENSE>
 @homepage: https://gitlab.com/Malfatti/SciScripts
+
+Simple script to load, filter and plot data.
 """
 
 import numpy as np
@@ -13,25 +15,31 @@ from sciscripts.Analysis import Analysis
 from sciscripts.Analysis.Plot import Plot
 
 
-# Load data
+# Load data from an open-ephys recording folder
 Folder = 'DataSet/2018-08-13_13-25-45_1416'
 Data, Rate = IO.DataLoader(Folder)
-Rec0 = Data['100']['0']['0'][:,:16]
-Rate0 = Rate['100']['0']
+
+
+# Select the 1st processor, 1st experiment, 1st recording, 1st 8 channels
+Proc = list(Data.keys())[0]             # Select 1st rec processor
+DataExp = list(Data[Proc].keys())[0]    # Select 1st experiment
+
+Rec0 = Data[Proc][DataExp]['0'][:,:8]
+Rate0 = Rate[Proc][DataExp]
 Time0 = np.arange(Rec0.shape[0])/Rate0
 
 
-# Plot 50ms of all channels
-Plot.AllCh(Rec0[:int(Rate0*0.05),:], Save=True, File='Plot1', Ext=['png'])
+# Plot 50ms of raw channels
+Plot.AllCh(Rec0[:int(Rate0*0.05),:], lw=1, Save=True, File='Plot1', Ext=['png'])
 
 
-# Filtering
-Rec0Theta = Analysis.FilterSignal(Rec0, Rate0, Frequency=[4,12], FilterOrder=2)
-Rec0Gamma = Analysis.FilterSignal(Rec0, Rate0, Frequency=[30,100], FilterOrder=3)
+# Filtering in theta and gamma bands
+Rec0Theta = Analysis.FilterSignal(Rec0, Rate0, Frequency=[4,12], Order=2)
+Rec0Gamma = Analysis.FilterSignal(Rec0, Rate0, Frequency=[30,100], Order=3)
 
 
 # Plot raw, theta and gamma
-Window = int(Rate0)
+Window = int(Rate0/2)
 plt = Plot.Return('plt')
 Fig, Axes = plt.subplots(1,3)
 Axes[0] = Plot.AllCh(Rec0[:Window,:], Time0[:Window], Ax=Axes[0], lw=0.7)
