@@ -67,6 +67,10 @@ def ABRPerCh(Data, Rate, TTLs, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500],
     ABRs = np.zeros((Len, Data.shape[1]), dtype=Data.dtype)
     ABRData = Analysis.FilterSignal(Data, Rate, FilterFreq, FilterOrder, FilterCoeff, Filter)
 
+    if 'float' in str(type(TTLs[0])):
+        if np.array(TTLs).all() == np.array(TTLs, dtype=int).all():
+            TTLs = np.array(TTLs, dtype=int)
+
     ABRs = Analysis.Slice(
         ABRData, TTLs,
         [int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate)],
@@ -76,7 +80,7 @@ def ABRPerCh(Data, Rate, TTLs, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500],
     return(ABRs)
 
 
-def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
+def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1, Verbose=False):
     """
     Extract peaks from `ABRs[RefKey][:,BestCh]`, where `BestCh` is the channel
     with the greatest Root-mean-square. The threshold for peaks are set as
@@ -172,18 +176,20 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
     strongest intensity, which should be considered the hearing threshold.
 
     """
+    FN = LatencyToPeaks.__name__.replace('sciscripts.','')
     Rev = False if '0' in ABRs else True
     Recs = sorted(ABRs.keys(), reverse=Rev)
 
     if len(Recs) == 1:
-        print('You need at least 2 recordings in ABRs dict to compare latencies.')
+        if Verbose: print(f'[{FN}] You need at least 2 recordings in ABRs dict to compare latencies.')
         return(None)
 
     if not RefKey: RefKey = Recs[0]
     BestCh = Analysis.GetStrongestCh(ABRs[RefKey])
 
-    FixedThreshold = ABRs[RefKey][:,BestCh].std()*Std
-    Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], FixedThreshold=FixedThreshold) for Rec in Recs]
+    # FixedThreshold = ABRs[RefKey][:,BestCh].std()*Std
+    # Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], FixedThreshold=FixedThreshold) for Rec in Recs]
+    Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], Std=Std) for Rec in Recs]
 
     Peaks = [_['Pos'] for _ in Peaks]
     if len(X): Peaks = [P[X[P] > 0] for P in Peaks]
@@ -222,7 +228,7 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
             Last = Peaks[R][AllPeaks[LocalRef][-1] < Peaks[R]][0]
 
             if Last not in RecPeaks:
-                # print('Before:', RecPeaks)
+                if Verbose: print(f'[{FN}] Before:', RecPeaks)
                 Ind = np.where((AllPeaks[0] <= Last))[0][0]
 
                 IntermedNo = (Ind)-len(RecPeaks)
@@ -250,7 +256,7 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
 
 
 ## Level 1
-def GetThreshold(ABRs, X=[], Std=1):
+def GetThreshold(ABRs, X=[], Std=1, Verbose=False):
     """
     Get hearing threshold from ABR traces as the lowest intensity evoking valid
     peaks. See `sciscripts.Analysis.ABRs.LatencyToPeaks?` for more details on
@@ -282,7 +288,7 @@ def GetThreshold(ABRs, X=[], Std=1):
         Index of the recording that evoked the smallest detectable response.
 
     """
-    Peaks = LatencyToPeaks(ABRs, X, Std=Std)
+    Peaks = LatencyToPeaks(ABRs, X, Std=Std, Verbose=Verbose)
     if Peaks is None or Peaks.mean() == -1:
         return(0)
 
@@ -291,7 +297,7 @@ def GetThreshold(ABRs, X=[], Std=1):
     return(Threshold)
 
 
-def LatencyPerFreq(Files, Freqs, Std=1):
+def LatencyPerFreq(Files, Freqs, Std=1, Verbose=False):
     """
     Under dev
     """
@@ -301,7 +307,7 @@ def LatencyPerFreq(Files, Freqs, Std=1):
         X = '/'.join(File.split('/')[:-1])+'/X.dat'
         X = IO.Bin.Read(X)[0]
 
-        Latencies[Freqs[F]] = LatencyToPeaks(ABRs, X, Std=Std)
+        Latencies[Freqs[F]] = LatencyToPeaks(ABRs, X, Std=Std, Verbose=Verbose)
 
         Thrs = [np.where((Latencies[Freqs[F]][:,_] == max(Latencies[Freqs[F]][:,_])))[0][-1] for _ in range(Latencies[Freqs[F]].shape[1])]
         Ind = np.where((Thrs == max(Thrs)))[0][0]
@@ -314,7 +320,7 @@ def LatencyPerFreq(Files, Freqs, Std=1):
     return(Latencies)
 
 
-def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], FilterOrder=4, Filter='bandpass', Save='', Return=True):
+def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], FilterOrder=4, Filter='bandpass', Save='', Return=True, Verbose=False):
     """
     Extract ABR traces from raw data.
 
@@ -369,7 +375,7 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,
         Array with time values based on `TimeWindow` matching `ABRs.shape[0]`.
 
     """
-
+    FN = Single.__name__.replace('sciscripts.','')
     X = Analysis.GetTime(TimeWindow, Rate)*1000
 
     if type(TTLCh) == int:
@@ -380,8 +386,8 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,
     if len(TTLs) and TTLs[0] != 'Broken':
         ABRs = ABRPerCh(Data[:,[_-1 for _ in ABRCh]], Rate, TTLs, TimeWindow, FilterFreq, FilterOrder, FilterCoeff='butter', Filter=Filter)
     else:
-        print('No TTLs in this recording.')
-        return(None)
+        if Verbose: print(f'[{FN}] No TTLs in this recording.')
+        return((None,None))
 
     if Save:
         IO.Bin.Write(X, '/'.join(Save.split('/')[:-2])+'/X.dat')
@@ -395,7 +401,7 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,
 
 
 ## Level 2
-def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Recs=[], Intensities=[], Save='', Return=True):
+def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Recs=[], Intensities=[], Save='', Return=True, Verbose=False):
     """
     Extract ABR traces from recordings at different intensities.
 
@@ -460,10 +466,12 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[60
         Array with time values based on `TimeWindow`.
 
     """
+    FN = Multiple.__name__.replace('sciscripts.','')
     if not len(Recs): Recs = sorted(Data.keys(), key=lambda x: int(x))
 
     ABRs = {}
     for R,Rec in enumerate(Recs):
+        if Verbose: print(f'[{FN}] Processing rec {Rec}...')
         Rec_R = Rec if not len(Intensities) else Intensities[R]
         ABRCh_R = ABRCh if type(ABRCh[0]) != list else ABRCh[R]
 
@@ -479,7 +487,7 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[60
 
         ABRs[Rec_R] = Single(
             Data[Rec], Rate, ABRCh_R, TTLCh_R, TimeWindow, FilterFreq,
-            File=Save_R, Return=Return
+            Save=Save_R, Return=True, Verbose=Verbose
         )[0]
 
     X = Analysis.GetTime(TimeWindow, Rate)*1000
@@ -487,6 +495,8 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[60
     if Save:
         IO.Bin.Write(X, '/'.join(Save.split('/')[:-1])+'/X.dat')
 
+    if Verbose: print(f'[{FN}] Done.')
+
     if Return:
         return(ABRs, X)
     else:
@@ -495,62 +505,91 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[60
 
 
 ## Level 3
-def GetThresholdsPerFreq(Folders, Std=1):
+def GetThresholdsPerFreq(Folders, Std=1, Verbose=False):
     """
     Under dev
     """
-    Thresholds = {'Thresholds': [], 'Freqs':[]}
+    Thresholds = {'Thresholds': [], 'Freqs':[], 'Animals':[]}
 
     for Folder in Folders:
-        ABR = IO.Bin.Read(Folder+'/ABRs', Verbose=False)[0]
+        ABR = IO.Bin.Read(Folder+'/ABRs', Verbose=Verbose)[0]
         Freqs = sorted(ABR.keys(), key=lambda i: int(i.split('-')[1]))
+        Animal = Folder.split('/')[-1].split('-')[1]
 
         for Freq in Freqs:
             Trial = 'Trial'+str(len(ABR[Freq])-2)
             Intensities = sorted(ABR[Freq][Trial], reverse=True, key=lambda x: int(x))
-            Threshold = GetThreshold(ABR[Freq][Trial], ABR[Freq]['X'], Std=Std)
+            Threshold = GetThreshold(ABR[Freq][Trial], ABR[Freq]['X'], Std=Std, Verbose=Verbose)
             Thresholds['Thresholds'].append(int(Intensities[Threshold]))
             Thresholds['Freqs'].append(Freq)
+            Thresholds['Animals'].append(Animal)
 
     Thresholds = {K: np.array(V) for K,V in Thresholds.items()}
 
     return(Thresholds)
 
-def GetWaveAmpPerFreq(Folders, Std=1):
+def GetWaveAmpPerFreq(Folders, Std=1, Factors=[], FactorNames=[], Verbose=False):
     """
     Under dev
     """
-    WaveAmps = {'Amps': [], 'Freqs':[]}
+    WaveAmps = {'Amps': [], 'Latencies':[], 'Freqs':[], 'Intensity':[], 'Animal':[], 'Folder':[]}
+    WaveAmps = {**WaveAmps, **{_:[] for _ in FactorNames}}
 
-    for Folder in Folders:
-        ABR = IO.Bin.Read(Folder+'/ABRs', Verbose=False)[0]
+    for F,Folder in enumerate(Folders):
+        Animal = Folder.split('/')[-1].split('-')[1]
+        ABR = IO.Bin.Read(Folder+'/ABRs', Verbose=Verbose)[0]
         Freqs = sorted(ABR.keys(), key=lambda i: int(i.split('-')[1]))
 
         for Freq in Freqs:
             Trial = 'Trial'+str(len(ABR[Freq])-2)
             Intensities = sorted(ABR[Freq][Trial], reverse=True, key=lambda x: int(x))
-            X = IO.Bin.Read(Folder+'/ABRs/'+Freq+'/X.dat', Verbose=False)[0]
-            Peaks = LatencyToPeaks(ABR[Freq][Trial], X, Std=Std)
+            X = IO.Bin.Read(Folder+'/ABRs/'+Freq+'/X.dat', Verbose=Verbose)[0]
+            Peaks = LatencyToPeaks(ABR[Freq][Trial], X, Std=Std, Verbose=Verbose)
             if Peaks is None or Peaks.mean() == -1:
-                WaveAmps['Amps'].append(np.zeros(5))
-                WaveAmps['Freqs'].append(Freq)
-                continue
+                for I,Int in enumerate(Intensities):
+                    WaveAmps['Amps'].append(np.empty((5))*np.nan)
+                    WaveAmps['Latencies'].append(np.empty((5))*np.nan)
+                    WaveAmps['Freqs'].append(Freq)
+                    WaveAmps['Intensity'].append(Int)
+                    WaveAmps['Animal'].append(Animal)
+                    WaveAmps['Folder'].append(Folder)
+                    for Fa,Factor in enumerate(Factors):
+                        WaveAmps[FactorNames[Fa]].append(Factor[F])
+            else:
+                for I,Int in enumerate(Intensities):
+                    WaveAmp = Analysis.GetAmpEnv(ABR[Freq][Trial][Int])[Peaks[I,:],0]
+                    WaveAmp[Peaks[I,:]==-1] = np.nan
+                    WaveLat = X[Peaks[I,:]]
+                    WaveLat[Peaks[I,:]==-1] = np.nan
 
-            WaveAmp = ABR[Freq][Trial][Intensities[0]][Peaks[0,:],0]
-            WaveAmps['Amps'].append(WaveAmp)
-            WaveAmps['Freqs'].append(Freq)
+                    WaveAmps['Amps'].append(WaveAmp)
+                    WaveAmps['Latencies'].append(WaveLat)
+                    WaveAmps['Freqs'].append(Freq)
+                    WaveAmps['Intensity'].append(Int)
+                    WaveAmps['Animal'].append(Animal)
+                    WaveAmps['Folder'].append(Folder)
+
+                    for Fa,Factor in enumerate(Factors):
+                        WaveAmps[FactorNames[Fa]].append(Factor[F])
 
     MaxLen = max([_.shape[0] for _ in WaveAmps['Amps']])
     for WA,WaveAmp in enumerate(WaveAmps['Amps']):
         if WaveAmp.shape[0] < MaxLen:
-            WaveAmps['Amps'][WA] = np.hstack((WaveAmp, -np.ones(MaxLen-WaveAmp.shape[0])))
+            WaveAmps['Amps'][WA] = np.hstack((
+                WaveAmp, np.empty((MaxLen-WaveAmp.shape[0]))*np.nan
+            ))
+
+            WaveAmps['Latencies'][WA] = np.hstack((
+                WaveAmps['Latencies'][WA],
+                np.empty((MaxLen-WaveAmp.shape[0]))*np.nan
+            ))
 
     WaveAmps = {K: np.array(V) for K,V in WaveAmps.items()}
 
     return(WaveAmps)
 
 
-def Session(Folders, Freqs, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Intensities=[], Proc='', ChannelMap=[], Save='', Return=True):
+def Session(Folders, Freqs, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Intensities=[], Proc='', Exp='', ChannelMap=[], Save='', Return=True, Verbose=False):
     """
     Extract ABR traces from recordings at different frequencies and intensities.
 
@@ -624,16 +663,21 @@ def Session(Folders, Freqs, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=
         Array with time values based on `TimeWindow`.
 
     """
+    FN = Session.__name__.replace('sciscripts.','')
     ABRs = {}
     for F, Folder in enumerate(Folders):
-        print(Folder.replace(os.environ['DATAPATH']+'/', '').replace(os.environ['HOME']+'/', ''))
-        Data, Rate = IO.DataLoader(Folder, Unit='uV', ChannelMap=ChannelMap)
+        if Verbose: print(f"[{FN}] {Folder}")
+        Data, Rate = IO.DataLoader(Folder, Unit='uV', ChannelMap=ChannelMap, Verbose=Verbose)
 
         if not len(Proc):
-            if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
-            else: ChNo, Proc = IO.OpenEphys.GetChNoAndProcs(Folder+'/settings.xml')
+            if len(Data.keys()) == 1: tProc = list(Data.keys())[0]
+            else: ChNo, tProc = IO.OpenEphys.GetChNoAndProcs(Folder+'/settings.xml')
+        else: tProc = Proc
+
+        tExp = list(Data[tProc].keys())[0] if not len(Exp) else Exp
+
+        Data, Rate = Data[tProc][tExp], Rate[tProc][tExp]
 
-        Data, Rate = Data[Proc]['0'], Rate[Proc]['0']
         TTLCh_F = TTLCh[F] if type(TTLCh) == list else TTLCh
         ABRCh_F = ABRCh[F] if type(ABRCh[0]) == list else ABRCh
 
@@ -641,14 +685,14 @@ def Session(Folders, Freqs, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=
             if Save.lower() == 'auto':
                 Save = os.environ['ANALYSISPATH'] + '/' + Folder.split('/')[-3]
 
-            XSavePath = '/'.join([Save, Folder.split('/')[-2], 'ABRs', Freqs[F]])
+            XSavePath = '/'.join([Save, 'ABRs', Freqs[F]])
             if os.path.isdir(XSavePath): Trial = 'Trial'+str(len(glob(XSavePath)))
             else: Trial = 'Trial0'
             SavePath = '/'.join([XSavePath, Trial])
         else:
             SavePath = ''
 
-        ABRs[Freqs[F]], X = Multiple(Data, Rate, ABRCh_F, TTLCh_F, TimeWindow, FilterFreq, Recs='all', Intensities=Intensities, Save=SavePath, Return=Return)
+        ABRs[Freqs[F]], X = Multiple(Data, Rate, ABRCh_F, TTLCh_F, TimeWindow, FilterFreq, Recs=[], Intensities=Intensities, Save=SavePath, Return=True, Verbose=Verbose)
 
         del(Data)
 
