@@ -9,8 +9,10 @@
 
 print('[Analysis.Analysis] Loading dependencies...')
 import numpy as np
+import re
 import scipy.signal as ssig
 import scipy.special as ssp
+from copy import deepcopy as dcp
 from itertools import tee
 from scipy import fftpack
 print('[Analysis.Analysis] Done.')
@@ -346,17 +348,23 @@ def GetNegEquiv(Number):
 
     Parameters
     ----------
-    Number: int or float
+    Number: int or float or array
         Number in the range 0-inf. If Number is < 0, it will be returned
         unmodified.
 
     Returns
     -------
-    NumberNeg: int or float
+    NumberNeg: int or float or array
         The representation of Number into the range 0 to -100.
 
     """
-    NumberNeg = Number if Number < 0 else -(100-(100/((Number+100)/100)))
+    if 'array' in str(type(Number)):
+        NumberNeg = dcp(Number)
+        N0 = NumberNeg[NumberNeg>0]
+        N0 = -(100-(100/((N0+100)/100)))
+        NumberNeg[NumberNeg>0] = N0
+    else:
+        NumberNeg = Number if Number < 0 else -(100-(100/((Number+100)/100)))
     return(NumberNeg)
 
 
@@ -731,7 +739,9 @@ def Pairwise(iterable):
 
 def PolygonArea(X,Y):
     """
-    Calculate the area of a polygon based on lists of x and y coordinates.
+    Calculate the area of a polygon based on lists of x and y coordinates using
+    the Shoelace formula.
+    NaNs in one of the arrays lead to drop of that value in both arrays.
 
     Parameters
     ----------
@@ -745,9 +755,13 @@ def PolygonArea(X,Y):
         Area of the polygon defined by the vertices at the provided
         coordinates.
 
-    Author: Madhi
-    Source: https://stackoverflow.com/a/30408825
+    Modified from @Madhi at https://stackoverflow.com/a/30408825
     """
+    if len(X) != len(Y):
+        raise ValueError('X and Y must have the same length.')
+
+    NaN = np.isnan(X)+np.isnan(Y)
+    X,Y = X[~NaN], Y[~NaN]
     Area = 0.5 * np.abs(np.dot(X, np.roll(Y,1)) - np.dot(Y, np.roll(X,1)))
     return(Area)
 
@@ -825,6 +839,18 @@ def RMS(Data):
     return(DataRMS)
 
 
+def SortNatural(s, _nsre=re.compile('([0-9]+)')):
+    """
+    Taken from Claudiu
+    @ https://stackoverflow.com/a/16090640
+
+    Naturally sort a list of strings.
+    """
+
+    return [int(text) if text.isdigit() else text.lower()
+            for text in _nsre.split(s)]
+
+
 def StrRange(Start='a', End='z', Step=1):
     """
     Get an alphabetically-ordered range of strings
@@ -1642,9 +1668,9 @@ def Spectrogram(Signal, Rate, Window='hann', WindowSize=None, Overlap=None, NFFT
         Power spectral density or power spectrum of x.
 
     """
-    if not WindowSize: WindowSize = len(Signal)//4
-    if not Overlap: Overlap = WindowSize//2
-    if not NFFT: NFFT = GetNFFT(WindowSize)
+    if WindowSize is None: WindowSize = len(Signal)//4
+    if Overlap is None: Overlap = WindowSize//2
+    if NFFT is None: NFFT = GetNFFT(WindowSize)
 
     F, T, Sxx = [], [], []
 
