@@ -10,6 +10,7 @@
 print('[Analysis.GPIAS] Loading dependencies...')
 import numpy as np
 from copy import deepcopy as dcp
+from glob import glob
 
 from sciscripts.Analysis import Analysis as sAnalysis
 from sciscripts.IO import IO
@@ -94,18 +95,57 @@ def ConvertTracesToArray(Traces):
     return(Array)
 
 
+def GetExpsIndexesDictSingleTrials(Exps, SliceSize, BGNormalize=True, Verbose=False):
+    """
+    Get index per freq per animal per exp.
+    Necessary for retest overriding (the last tested is always the correct one).
+    """
+    Indexes_IFAE_ST = {}
+    Keys = [['Gap','NoGap', 'GPIASIndex']]
+
+    for E, Exp in Exps.items():
+        if E not in Indexes_IFAE_ST: Indexes_IFAE_ST[E] = {}
+
+        for File in sorted(Exp):
+            GPIASRecST = IO.Bin.Read(f'{File}/GPIASAllTrials', Verbose=Verbose, AsMMap=False)[0]
+            if 'Gap' in GPIASRecST.keys() and 'NoGap' in GPIASRecST.keys():
+                fr = glob(f'{File}/GPIASAllTrials/*')[0].split('/')[-1]
+                GPIASRecST = {fr: GPIASRecST}
+
+            X = IO.Bin.Read(f'{File}/X.dat', Verbose=Verbose, AsMMap=False)[0]
+
+            Animal = File.split('/')[-1].split('-')[1]
+            if Animal not in Indexes_IFAE_ST[E]: Indexes_IFAE_ST[E][Animal] = {}
+
+            SliceSamples = np.where((X>=0)*(X<SliceSize*1000))[0].shape[0]
+
+            GIST = {
+                F: IndexCalc(Freq, X, SliceSamples, Keys, BGNormalize)['GPIASIndex']
+                for F,Freq in GPIASRecST.items()
+            }
+
+            Indexes_IFAE_ST[E][Animal] = {**Indexes_IFAE_ST[E][Animal], **{
+                K: sAnalysis.GetNegEquiv(V)
+                for K, V in GIST.items()
+            }}
+
+    Indexes_IFAE_ST = ConvertIndexesToArray(Indexes_IFAE_ST)
+    return(Indexes_IFAE_ST)
+
+
 def GetExpsIndexesDict(Exps, Verbose=False):
     """
     Get index per freq per animal per exp.
     Necessary for retest overriding (the last tested is always the correct one).
     """
-    Indexes_IFAE, Traces_IFAE = {}, {}
+    Indexes_IFAE, Traces_IFAE, X = {}, {}, []
     for E, Exp in Exps.items():
         if E not in Indexes_IFAE: Indexes_IFAE[E], Traces_IFAE[E] = {}, {}
 
         for File in sorted(Exp):
             GPIASRec = IO.Bin.Read(f'{File}/GPIAS', Verbose=Verbose, AsMMap=False)[0]
-            X = IO.Bin.Read(f'{File}/X.dat', Verbose=Verbose, AsMMap=False)[0]
+            if not len(X):
+                X = IO.Bin.Read(f'{File}/X.dat', Verbose=Verbose, AsMMap=False)[0]
 
             Animal = File.split('/')[-1].split('-')[1]
             if Animal not in Indexes_IFAE[E]:
