@@ -18,12 +18,8 @@ def Expectation(c):
     return(E)
 
 
-def Normalize(Files, Min=1, Max=99):
-    IMGs, IMGsNorm = [], []
-    for File in Files:
-        IMG = plt.imread(File)
-        IMGs.append(IMG)
-
+def NormalizeIMGs(IMGs, Min=1, Max=99):
+    IMGsNorm = []
     AllMax = max([_.max() for _ in IMGs])
     for I,IMG in enumerate(IMGs):
         IMG2 = IMG/AllMax
@@ -45,6 +41,17 @@ def Normalize(Files, Min=1, Max=99):
     return(IMGsNorm)
 
 
+def Normalize(Files, Min=1, Max=99):
+    # IMGs = []
+    # for File in Files:
+        # IMG = plt.imread(File)
+        # IMGs.append(IMG)
+
+    IMGs = [plt.imread(File) for File in Files]
+    IMGsNorm = NormalizeIMGs(IMGs, Min, Max)
+    return(IMGsNorm)
+
+
 def OptimalGain(StD):
     OG = 1/StD
     return(OG)
