@@ -13,6 +13,8 @@ from glob import glob
 from sciscripts.Analysis.Plot import Units as UnitsPlot
 from sciscripts.IO import IO
 
+ScriptName = 'Analysis.Plot.Klusta'
+
 
 def Raster_Full(SpkClusters, UnitsId, SpkRecs, SpkSamples, Rate, Rec, Offset=0, PulseDur=None, TTLs=[],
                 Ax=None, AxArgs={}, File='RasterFull', Ext=['svg'], Save=False, Show=True):
@@ -235,6 +237,10 @@ def Features(UnitRec, FigPath, Exp, BinSize=None, ExtraInfo={}, Ext=['svg'], Sav
 
 
 def AllPlots(AnalysisPath, Stims, FigPath=None, BinSize=None, Ext=['svg'], Save=False, Show=True):
+    if not IO.Asdf.Avail:
+        print(f'[{ScriptName}] {e}: Please install the `hdf5` library to use this module.')
+        return(None)
+
     if not FigPath: FigPath = AnalysisPath + '/Plots'
 
     AsdfFiles = sorted(glob(AnalysisPath+'/**/*_AllUnits.asdf', recursive=True))
