@@ -12,6 +12,9 @@ import os
 import numpy as np
 from itertools import accumulate#, combinations
 from matplotlib.colors import to_rgba
+from matplotlib.collections import PatchCollection
+from matplotlib.patches import Circle
+
 from subprocess import check_output
 
 from sciscripts.Analysis.Analysis import Pairwise
@@ -669,7 +672,7 @@ def AllCh(Data, X=[], Colors=[], Labels=[], Leg=[], SpaceAmpF=1, ScaleBar=0, lw=
     return(Result)
 
 
-def BoxPlots(Data, X=[], EdgeColors=[], FaceColors=[], FaceAlpha=[], LinesAmpF=1, Width=None, Means=True,
+def BoxPlots(Data, X=[], EdgeColors=[], FaceColors=[], FaceAlpha=[], LinesAmpF=1, Width=None, Means=True, PlotArgs={},
              Ax=None, AxArgs={}, File='Boxplots', Ext=['svg'], Save=False, Show=True):
 
     BPData = [[_ for _ in d if not np.isnan(_)] for d in Data]
@@ -679,9 +682,10 @@ def BoxPlots(Data, X=[], EdgeColors=[], FaceColors=[], FaceAlpha=[], LinesAmpF=1
     if not len(FaceColors): FaceColors = ['k']*len(BPData)
     if not len(FaceAlpha): FaceAlpha = [0.2]*len(BPData)
 
+    PA = {**{'patch_artist':True, 'showmeans':False}, **PlotArgs}
+
     Fig, Ax, ReturnAx = FigAx(Ax)
-    BoxPlot = Ax.boxplot(BPData, positions=X, widths=Width, showmeans=False,
-                         patch_artist=True)
+    BoxPlot = Ax.boxplot(BPData, positions=X, widths=Width, **PA)
 
     for I in range(len(BoxPlot['fliers'])):
         BoxPlot['fliers'][I].set_markeredgecolor(EdgeColors[I])
@@ -711,6 +715,64 @@ def BoxPlots(Data, X=[], EdgeColors=[], FaceColors=[], FaceAlpha=[], LinesAmpF=1
     return(Result)
 
 
+def Circles(
+        X, Y, Radius, CirclesArgs={},
+        Ax=None, AxArgs={}, File='Circles', Ext=['svg'], Save=False, Show=True
+    ):
+    """
+    Make a scatter of circles plot of X vs Y, where X and Y are sequence
+    like objects of the same lengths. The size of circles are in data scale.
+
+    Parameters
+    ----------
+    X,Y : scalar or array_like, shape (n, )
+        Input data
+    Radius : scalar or array_like, shape (n, )
+        Radius of circle in data unit.
+    CirclesArgs : `~matplotlib.collections.Collection` properties
+        Eg. alpha, edgecolor(ec), facecolor(fc), linewidth(lw), linestyle(ls),
+        norm, cmap, transform, etc.
+
+    Returns
+    -------
+    paths : `~matplotlib.collections.PathCollection`
+
+    Examples
+    --------
+    a = np.arange(11)
+    Circles(a, a, a*0.2, alpha=0.5, edgecolor='none')
+    plt.colorbar()
+
+    License
+    --------
+    This code is under [The BSD 3-Clause License]
+    (http://opensource.org/licenses/BSD-3-Clause)
+
+    Modified from @Syrtis-Major at https://stackoverflow.com/a/24567352
+    """
+
+    plt = Return('plt')
+    Fig, Ax, ReturnAx = FigAx(Ax)
+
+    if 'fc' in CirclesArgs.keys(): CirclesArgs['facecolor'] = CirclesArgs.pop('fc')
+    if 'ec' in CirclesArgs.keys(): CirclesArgs['edgecolor'] = CirclesArgs.pop('ec')
+    if 'ls' in CirclesArgs.keys(): CirclesArgs['linestyle'] = CirclesArgs.pop('ls')
+    if 'lw' in CirclesArgs.keys(): CirclesArgs['linewidth'] = CirclesArgs.pop('lw')
+
+    patches = [Circle((x, y), r) for x, y, r in np.broadcast(X, Y, Radius)]
+    collection = PatchCollection(patches, **CirclesArgs)
+
+    Ax.add_collection(collection)
+    Ax.autoscale_view()
+
+    if not Ax:
+        Ax.set_xlim([X[0]-(XSpread*2), X[-1]+(XSpread*2)])
+        Ax.set_xticks(X)
+
+    Result = SaveShow(ReturnAx, Fig, Ax, AxArgs, File, Ext, Save, Show)
+    return(Result)
+
+
 def Comodulogram(Cmdlgrm, AmpFreq, PhaseFreq, CMap='inferno',
                  Ax=None, AxArgs={}, File='Comodulogram', Ext=['pdf'], Save=False, Show=True):
 
