@@ -59,12 +59,12 @@ def GetMeasurements(System, Setup, Rate, MicSens_VPa, Noise=[]):
                                       dtype='float32')
                 PSD[K][:,A,F] = psd[K]
 
-    SoundIntensity['Freqs'] = Freqs
-    SoundIntensity['AmpFs'] = AmpFs
-    SoundIntensity['Dimensions'] = ['AmpF', 'Freq']
-    PSD['Freqs'] = Freqs
-    PSD['AmpFs'] = AmpFs
-    PSD['Dimensions'] = ['Data', 'AmpF', 'Freq']
+    SoundIntensity['Freqs'] = np.array(Freqs)
+    SoundIntensity['AmpFs'] = np.array(AmpFs)
+    SoundIntensity['Dimensions'] = np.array(['AmpF', 'Freq'])
+    PSD['Freqs'] = np.array(Freqs)
+    PSD['AmpFs'] = np.array(AmpFs)
+    PSD['Dimensions'] = np.array(['Data', 'AmpF', 'Freq'])
 
     return(SoundIntensity, PSD)
 
@@ -73,21 +73,32 @@ def TexTableWrite(SoundIntensity, DataPath):
     if not AvailPandas:
         raise ModuleNotFoundError(f'[{ScriptName}] Module `pandas` not available.')
 
-    TexTable = DataFrame([[[float(AmpF)] + [SoundIntensity['dB'][A,F]]
-                           for F,Freq in enumerate(SoundIntensity['Freqs'])]
-                         for A,AmpF in enumerate(SoundIntensity['AmpFs'])])
+    TexTable =  DataFrame(
+        [['Volt.'] + SoundIntensity['Freqs'].tolist()] + [
+            [float(AmpF)]+[
+                round(SoundIntensity['dB'][A,F], 2)
+                for F,Freq in enumerate(SoundIntensity['Freqs'])
+            ]
+            for A,AmpF in enumerate(SoundIntensity['AmpFs'])
+        ]
+    )
+
+    ssys, sset = DataPath.split('/')[-2:]
 
     with open(DataPath+'/'+'IntensityTable.tex', 'w') as File:
         File.write(
         r"""%% Configs =====
-\documentclass[12pt,a4paper]{report}
+\documentclass[12pt,a4paper,landscape]{article}
 \usepackage[left=0.5cm,right=0.5cm,top=0.5cm,bottom=0.5cm]{geometry}
 \usepackage{longtable}
+\title{Sound measurements}
+\author{""" + f'{ssys} {sset}' + r"""}
 % Document ======
 \begin{document}
-\section{Sound measurements}
+\maketitle
+\scriptsize
 """     )
-        File.write(TexTable.to_latex(longtable=True))
+        File.write(TexTable.to_latex(longtable=True, index=False, index_names=False))
         File.write(r"""
 \end{document}
 """     )
@@ -109,8 +120,8 @@ def Run(Rate, System, Setup, MicSens_dB=None, MicSens_VPa=None, **Kws):
 
     ## Save analyzed data
     print('Saving analyzed data...')
-    IO.DataWriter(SoundIntensity, DataPath+'/SoundIntensity', 'dat')
-    IO.DataWriter(PSD, DataPath+'/PSD', 'dat')
+    IO.Bin.Write(SoundIntensity, DataPath+'/SoundIntensity')
+    IO.Bin.Write(PSD, DataPath+'/PSD')
 
     if AvailPandas: TexTableWrite(SoundIntensity, DataPath)
 
