@@ -7,7 +7,7 @@
 @homepage: https://gitlab.com/Malfatti/SciScripts
 """
 
-print('[Analysis.Units.Units] Importing dependencies...')
+print('[Analysis.Units.Units] Loading dependencies...')
 
 import os
 import numpy as np
