@@ -7,15 +7,16 @@
 @homepage: https://gitlab.com/Malfatti/SciScripts
 """
 
-print('[Exps.Arduino] Loading dependencies...')
-import os
+ScriptName = 'Exps.Arduino'
+print(f'[{ScriptName}] Loading dependencies...')
+import inspect, os
 import matplotlib.animation as animation
 import matplotlib.pyplot as plt
 
 from datetime import datetime
 
 from sciscripts.IO import Arduino, Txt
-print('[Exps.Arduino] Done.')
+print(f'[{ScriptName}] Done.')
 
 
 def CheckPiezoAndTTL(XLim=(0, 192), YLim=(-5, 1028), FramesPerBuf=192, BaudRate=115200):
@@ -78,6 +79,7 @@ def ReadAnalogIn(Channels, Rate, Interp=True, FramesPerBuf=128, AnimalName='Anim
 
     The shape will be in the filename.
     """
+    FunctionName = inspect.stack()[0][3]
 
     ArduinoObj = Arduino.CreateObj(115200)
 
@@ -91,9 +93,15 @@ def ReadAnalogIn(Channels, Rate, Interp=True, FramesPerBuf=128, AnimalName='Anim
 
     DataLen = 0
     try:
-        print('Recording..')
+        print(f'[{ScriptName}.{FunctionName}] [00:00:00] Recording..')
+        # ThisSec = 1; TimeStart = 0
         while True:
             Data, Time = Arduino.GetSerialData(Channels, Rate, ArduinoObj, FramesPerBuf, Interp)
+            # if TimeStart == 0: TimeStart = Time[0]
+            # if (Time[-1]-TimeStart)//10 >= ThisSec:
+                # ThisTime = datetime.strptime(str(ThisSec*10), '%S').strftime('%H:%M:%S')
+                # print(f'[{ScriptName}.{FunctionName}] [{ThisTime}] Recording..')
+                # ThisSec += 1
             with open(Date+'.dat', 'ab') as File: File.write(Data.tobytes())
             with open(Date+'_Time.dat', 'ab') as File: File.write(Time.tobytes())
             DataLen += Data.shape[0]
