@@ -77,27 +77,31 @@ if SoundCard.Avail:
 
 
     ## Level 1
-    def CalibrateInput(Repetitions, TestAmp, SBOutAmpF, Freq, WaveDur, Rate, BlockSize=None, Channel=1):
+    def CalibrateInput(Repetitions, TestAmp, SBOutAmpF, Freq, WaveDur, Rate, BlockSize=None, Channels=[1]):
         """
         Read signal from sound card input. You have to apply a known amplitude
         signal (a sine wave, for example) to the sound card input, so you can
         check if the voltage you applied is the voltage being read by the sound
         card.
         """
-        SoundCard.AudioSet(Rate, BlockSize, Channels=1)
+        SoundCard.AudioSet(Rate, BlockSize, Channels=len(Channels))
         Pulse = SigGen.SineWave(Rate, Freq, TestAmp*SBOutAmpF, WaveDur)
-        SBInAmpF = np.zeros(Repetitions, dtype=np.float32)
+        SBInAmpF = np.zeros((Repetitions,len(Channels)), dtype=np.float32)
         print('Connect the system output to the system input')
         input('and press enter to proceed.')
 
         for aa in range(Repetitions):
             print('Measuring... ', end='')
-            Rec = SoundCard.ReadWrite(Pulse, OutMap=[Channel], InMap=[Channel])
+            Rec = SoundCard.ReadWrite(Pulse, OutMap=Channels, InMap=Channels)
             print('Done.')
 
-            #SBInAmpF[aa] = (max(Rec)-(min(Rec)))/2
-            SBInAmpF[aa] = (max(Rec[2000:])-(min(Rec[2000:])))/2
-            print(SBInAmpF[aa])
+            if len(Rec.shape)==1:
+                Rec = Rec.reshape((Rec.shape[0],1))
+
+            for Ch in range(Rec.shape[1]):
+                SBInAmpF[aa,Ch] = (max(Rec[2000:,Ch])-(min(Rec[2000:,Ch])))/2
+
+            print(SBInAmpF[aa,:])
 
         if SBInAmpF.mean() == 0:
             raise ValueError('The measured signal is 0V. Is the mic on?')
@@ -109,18 +113,18 @@ if SoundCard.Avail:
         return(SBInAmpF)
 
 
-    def CalibrateOutput(Freq, WaveDur, Rate, BlockSize=None, Channel=1):
+    def CalibrateOutput(Freq, WaveDur, Rate, BlockSize=None, Channels=[1]):
         """
         Write sine waves of 1V to sound card output. This function helps to get the
         sound card amplification factor, which is how much it is increasing or
         decreasing the signal written to it.
         """
-        SoundCard.AudioSet(Rate, BlockSize, Channels=1)
+        SoundCard.AudioSet(Rate, BlockSize, Channels=len(Channels))
         Pulse = SigGen.SineWave(Rate, Freq, 1, WaveDur)
 
         print('Plug the output in an oscilloscope')
         input('and press enter to start.')
-        SoundCard.Write(Pulse, [Channel]);
+        SoundCard.Write(Pulse, Channels);
         # SBOutAmpF is the generated signal divided by the measured signal
         Amp = input('Measured amplitude: ')
         SBOutAmpF = 1/float(Amp)
@@ -135,17 +139,17 @@ if SoundCard.Avail:
 
 
     ## Level 2
-    def RunCalibration(Freq, WaveDur, Repetitions, System, Rate, BlockSize=None, Channel=1, **Kws):
+    def RunCalibration(Freq, WaveDur, Repetitions, System, Rate, BlockSize=None, Channels=[1], **Kws):
         DataPath = CalibrationPath + '/' + System
 
         AmpF = {}
-        AmpF['OutAmpF'] = CalibrateOutput(Freq, WaveDur, Rate, BlockSize, Channel)
-        AmpF['InAmpF'] = CalibrateInput(Repetitions, 1, AmpF['OutAmpF'], Freq, WaveDur, Rate, BlockSize, Channel)
+        AmpF['OutAmpF'] = CalibrateOutput(Freq, WaveDur, Rate, BlockSize, Channels)
+        AmpF['InAmpF'] = CalibrateInput(Repetitions, 1, AmpF['OutAmpF'], Freq, WaveDur, Rate, BlockSize, Channels)
         Noise = GetBasalNoise(WaveDur, Rate, BlockSize)
         Noise *= AmpF['InAmpF']
 
         IO.Txt.Write(AmpF, DataPath+'/AmpF.txt')
-        IO.DataWriter(Noise, DataPath+'/Noise.dat', 'dat')
+        IO.Bin.Write(Noise, DataPath+'/Noise.dat')
 
         print('Calibration finished for', System)
         return(None)
