@@ -15,6 +15,7 @@ from glob import glob
 from scipy import sparse
 
 from sciscripts.IO import Txt
+from sciscripts.Analysis.Analysis import IsInt
 
 
 def PathToDict(Path, Value=None):
@@ -60,17 +61,37 @@ def MergeDictsAndContents(D1, D2):
 
 
 def DictToList(Data):
-    Keys = sorted(Data.keys(), key=lambda x: int(x.split('_')[-1]))
-    Data = [
-        DictToList(Data[K])
-            if type(Data[K]) == dict
-            and not False in ['_' in _ for _ in Data[K].keys()]
-            and len(np.unique(['_'.join(_.split('_')[:-1]) for _ in Data[K].keys()])) == 1
-        else Data[K]
-        for K in Keys
-    ]
+    IsList = (
+        (type(Data) == dict) and
+        (not False in ['_' in _ for _ in Data.keys()]) and
+        (len(np.unique([
+            '_'.join(_.split('_')[:-1]) for _ in Data.keys()
+        ])) == 1) and
+        (not False in [IsInt(_.split('_')[-1]) for _ in Data.keys()])
+    )
+    # print('IsList:',IsList)
 
-    return(Data)
+    if type(Data) == dict and not IsList:
+        DataList = {K: DictToList(V) for K,V in Data.items()}
+    elif IsList:
+        Keys = sorted(Data.keys(), key=lambda x: int(x.split('_')[-1]))
+        Inds = sorted([int(x.split('_')[-1]) for x in Data.keys()])
+        DataList = [[] for _ in range(max(Inds)+1)]
+
+        for i,K in zip(Inds,Keys):
+            if ((type(Data[K]) == dict)
+                    and (not False in ['_' in _ for _ in Data[K].keys()])
+                    and (len(np.unique([
+                        '_'.join(_.split('_')[:-1]) for _ in Data[K].keys()
+                    ])) == 1)
+                    and (not False in [IsInt(_.split('_')[-1]) for _ in Data.keys()])):
+                DataList[i] = DictToList(Data[K])
+            else:
+                DataList[i] = Data[K]
+    else:
+        DataList = Data
+
+    return(DataList)
 
 
 def Read(File, ChList=[], Info={}, Verbose=False, AsMMap=True):
@@ -87,7 +108,7 @@ def Read(File, ChList=[], Info={}, Verbose=False, AsMMap=True):
         - an Info dict containing Info['Shape'] and Info['DType']
     """
 
-    if '.' not in File:
+    if '.' not in File.split('/')[-1]:
         Data = {}
         Files = [glob(_.split('-Info.dict')[0]+'.*')[0]
                  for _ in glob(File+'/**/*-Info.dict', recursive=True)]
@@ -110,21 +131,18 @@ def Read(File, ChList=[], Info={}, Verbose=False, AsMMap=True):
 
         # LastCommon = LastCommon[-1]
         LastCommon += '/'
+        # print('REL')
 
         for d,D in enumerate(Files):
             Path = '.'.join(D.split('.')[:-1])
             Path = Path.split(LastCommon)[-1]
             if Verbose: print('Loading', Path, '...')
-            MergeDicts(Data, PathToDict(Path, Read(D, ChList, Info, AsMMap=AsMMap)[0]))
+            MergeDicts(Data, PathToDict(Path, Read(D, ChList, Info, Verbose, AsMMap)[0]))
 
-        if not False in ['_' in _ for _ in Data.keys()]:
-            if len(np.unique(['_'.join(_.split('_')[:-1]) for _ in Data.keys()])) == 1:
-                try:
-                    Data = DictToList(Data)
-                except ValueError:
-                    if len(Data.keys()) == 1:
-                        Data = Data[list(Data.keys())[0]]
+        if len(Data.keys())==1 and list(Data.keys())[0]==File.split('/')[-1]:
+            Data = Data[list(Data.keys())[0]]
 
+        Data = DictToList(Data)
 
         if type(Data) == dict \
                 and sorted(Data.keys()) == ['data', 'indices', 'indptr'] \
@@ -170,7 +188,7 @@ def Write(Data, File, Info={}):
         Write(np.array(Data).reshape(1), File, Info)
 
     elif 'csc_matrix' in str(type(Data)):
-        EFile = File.split('.')[0]
+        EFile = '.'.join(File.split('.')[:-1]) if '.' in File else File
 
         Write(
             {
@@ -193,7 +211,7 @@ def Write(Data, File, Info={}):
         Write(np.array(Data).reshape(1), File, Info)
 
     else:
-        if '.' not in File: File +='.dat'
+        if '.' not in File.split('/')[-1]: File +='.dat'
         if '/' in File: os.makedirs('/'.join(File.split('/')[:-1]), exist_ok=True)
 
         # Get info and generate path
@@ -202,8 +220,11 @@ def Write(Data, File, Info={}):
         Info['Flags'] = {}
 
         for Flag in ['C_CONTIGUOUS', 'F_CONTIGUOUS', 'OWNDATA', 'WRITEABLE',
-                     'ALIGNED', 'UPDATEIFCOPY']:
-            Info['Flags'][Flag] = Data.flags[Flag]
+                     'ALIGNED', 'UPDATEIFCOPY', 'WRITEBACKIFCOPY']:
+            try:
+                Info['Flags'][Flag] = Data.flags[Flag]
+            except KeyError:
+                pass
 
         InfoFile = '.'.join(File.split('.')[:-1]) + '-Info.dict'
 
