@@ -79,7 +79,7 @@ def RunProcess(Cmd, LogFile=''):
     return(ReturnCode)
 
 
-def MultiProcess(Function, Args, Procs=8):
+def MultiProcess(Function, Args, Procs=8, Verbose=False):
     TotalNo = len(Args)
     ProcLists = [[] for _ in range(0, TotalNo, Procs)]
 
@@ -88,7 +88,8 @@ def MultiProcess(Function, Args, Procs=8):
 
     for ProcList in ProcLists:
         for Proc in ProcList:
-            Proc.start(); print('PID =', Proc.pid)
+            Proc.start()
+            if Verbose: print('PID =', Proc.pid)
         Proc.join()
 
     return(None)
