@@ -5,11 +5,13 @@
 @date: 20170118
 @license: GNU GPLv3 <https://gitlab.com/malfatti/SciScripts/raw/master/LICENSE>
 @homepage: https://gitlab.com/Malfatti/SciScripts
+
+Functions for reading and writing tar files [under development].
 """
 
 import os, tarfile
 
-### Level 0 ###
+
 def TarWrite(FileList, File):
     if '/' in File: os.makedirs('/'.join(File.split('/')[:-1]), exist_ok=True)
     with tarfile.open(File, 'a') as F:
