@@ -8,11 +8,12 @@
 """
 
 import numpy as np
-import os
+import os, unicodedata
 
 from ast import literal_eval
 
 
+# Level 0
 def DictFlat(Var, UpKey='', KeySep='_', Flat={}):
     if type(Var) == dict:
         for K, V in Var.items():
@@ -31,21 +32,57 @@ def DictListsToArrays(DictLists):
         DictArrays = [{k: DictListsToArrays(v) for k,v in _.items()} for _ in DictLists]
     else:
         DictArrays = np.array(DictLists)
+        if (
+                'NaN' in np.ravel(DictArrays).tolist()
+                or 'inf' in np.ravel(DictArrays).tolist()
+                or '-inf' in np.ravel(DictArrays).tolist()
+            ):
+            DictArrays = DictArrays.astype(float)
 
     return(DictArrays)
 
-def DictObjToList(Dict):
-    for K,V in Dict.items():
-        if type(V) == dict: Dict[K] = DictObjToList(V)
 
-        elif type(V) == np.ndarray and V.dtype == np.dtype('O'):
-            Dict[K] = V.tolist()
-            if K in ('p', 'p.adj') and None in V:
-                Dict[K] = np.array([_ if _ is not None else np.nan for _ in V])
+def DictArraysToLists(DictArrays):
+    if type(DictArrays) == dict:
+        DictLists = {k: DictArraysToLists(v) for k,v in DictArrays.items()}
+    elif type(DictArrays) in (list,tuple):
+        DictLists = [DictArraysToLists(_) for _ in DictArrays]
+    elif type(DictArrays) == np.ndarray:
+        DictLists = DictArrays.tolist()
+    else:
+        DictLists = dcp(DictArrays)
 
-        else: pass
+    return(DictLists)
+
+
+def FixFileName(Name):
+    if not len(Name) or type(Name) != str: return('')
+    New = Name[:]
+
+    if '&' in New: New = New.replace('&',' and ')
+
+    for C in ['"',"'",'’','`','!','@','#','$','%','*','+','=','?',',']:
+        if C in New: New = New.replace(C,'')
+
+    for C in ['(',')','[',']','{','}','<','>','|','/','\\',';',':']:
+        if C in New: New = New.replace(C,'_')
+
+    if ' ' in New:
+        New = New.title()
+        New = New.replace(' ', '')
+
+    New = ''.join((c for c in unicodedata.normalize('NFD', New) if unicodedata.category(c) != 'Mn'))
+
+    if New[0] == New[0].lower():
+        New = list(New)
+        New[0] = New[0].upper()
+        New = ''.join(New)
+
+    if '.' in New:
+        New = '.'.join(New.split('.')[:-1]) + '.' + New.split('.')[-1].lower()
+
+    return(New)
 
-    return(Dict)
 
 def Print(value, htchar='    ', itemchar=' ', breaklineat='auto', lfchar='\n', indent=0):
     ''' Modified from y.petremann's code.
@@ -90,6 +127,11 @@ def Print(value, htchar='    ', itemchar=' ', breaklineat='auto', lfchar='\n', i
         return items
 
     else:
+        if type(value) == float and np.isnan(value):
+            value = 'NaN'
+        elif type(value) == float and np.isinf(value):
+            value = 'inf'
+
         return repr(value)
 
 
@@ -98,12 +140,14 @@ def Read(File):
     return(Dict)
 
 
+# Level 1
 def Write(Var, File):
     if '/' in File: os.makedirs('/'.join(File.split('/')[:-1]), exist_ok=True)
     with open(File, 'w') as F: F.write(Print(Var))
     return(None)
 
 
+# Level 2
 def InfoWrite(InfoFile, **All):
     DataInfo = {'InfoFile': InfoFile}
     for K in ['AnimalName', 'CageName', 'StimType']:
